# RDF

Transforms an input RDF model via the operations specified in the config file. This uses the default 'Handler' because no input format was specified.

```sh
brickify input.ttl --output bldg.ttl --config template.yml
```

**OR**

```sh
brickify input.ttl --output bldg.ttl --config template.json
```
